@@ -1,8 +1,12 @@
 import os
 import subprocess
 import requests
-from typer import Typer
+from typer import Typer, echo
 from .credentials import parse_credentials
+from tabulate import tabulate
+
+
+TIMEOUT_SECONDS = 3 * 60
 
 
 def execute_bash_command(cmd):
@@ -49,11 +53,28 @@ def connect():
 
 
 @app.command()
-def init(project_name: str):
-    """initialize a new project"""
+def create(project_name: str):
+    """create a new project"""
     # 1.
     execute_bash_command(f'mkdir -p {project_name}')
     execute_bash_command(f'touch {project_name}/supadef.yml')
+    body = {
+        'name': project_name
+    }
+    response = requests.post("https://supadef.com/project", headers=get_auth_headers(), json=body, timeout=TIMEOUT_SECONDS)
+    print(response.status_code)
+    print(response.json())
+
+
+@app.command()
+def destroy(project_name: str):
+    """destroy a project"""
+    body = {
+        'name': project_name
+    }
+    response = requests.delete("https://supadef.com/project", headers=get_auth_headers(), json=body, timeout=TIMEOUT_SECONDS)
+    print(response.status_code)
+    print(response.json())
 
 
 @app.command()
@@ -63,6 +84,11 @@ def projects():
     print(response.status_code)
     print(response.json())
 
+    __projects = response.json()
+    headers = ['state', 'name']
+    table = [[p[x] for x in headers] for p in __projects]
+    echo(tabulate(table, headers=headers))
+
 
 @app.command()
 def push():
